<template>
  <div class="app-container">
    <el-card>
      <el-table v-loading="" :data="tableData1" border style="width: 100%;max-height: 300px;" height="300px" size="mini">
        <el-table-column label="供应商" align="center" min-width="170">
          <template slot-scope="scope">
            {{ scope.row.供应商名称 }}
          </template>
        </el-table-column>
        <el-table-column label="请款时间" align="center" min-width="150">
          <template slot-scope="scope">
            {{ scope.row.请款时间 }}
          </template>
        </el-table-column>
        <el-table-column label="请款人" align="center" min-width="100">
          <template slot-scope="scope">
            {{ scope.row.姓名 }}
          </template>
        </el-table-column>
        <el-table-column label="请款金额" align="center" min-width="100" prop="请款金额">
          <template slot-scope="scope">
            {{ scope.row.请款金额 }}
          </template>
        </el-table-column>
        <el-table-column label="审核" align="center" width="320">
          <template slot-scope="scope">
            <el-popover placement="right" width="400" trigger="click">
              <el-table :data="gridData1" stripe size="mini" show-summary>
                <el-table-column width="50" align="center" type="index" label="序号"/>
                <el-table-column min-width="150" align="center" label="采购合同编号">
                  <template slot-scope="scope">
                    {{ scope.row.采购合同编号 }}
                  </template>
                </el-table-column>
                <el-table-column min-width="100" align="center" label="合同总额" prop="请款金额">
                  <template slot-scope="scope">
                    {{ scope.row.请款金额 }}
                  </template>
                </el-table-column>
              </el-table>
              <el-button slot="reference" type="success" size="mini" icon="el-icon-search" style="margin-right: 10px" @click="searchTable01(scope.row)">查看详情</el-button>
            </el-popover>
            <el-button type="primary" size="mini" icon="el-icon-check" @click="yesApproval(scope.row)">通过</el-button>
            <el-button type="danger" size="mini" icon="el-icon-close" @click="noApproval(scope.row)">不通过</el-button>
          </template>
        </el-table-column>
      </el-table>
      <div class="block" style="margin-top: 10px;">
        <el-pagination
          :current-page="pageCurrent1"
          :page-sizes="[10, 20, 30, 40]"
          :page-size="pageSize1"
          :total="total1"
          style="display:inline-block;width:50%"
          layout="total, sizes, prev, pager, next, jumper"
          @size-change="handleSizeChange1"
          @current-change="handleCurrentChange1"/>
      </div>
    </el-card>

    <el-card>
      <el-table v-loading="" :data="tableData2" border style="width: 100%;max-height: 300px;" height="300px" size="mini">
        <el-table-column label="供应商" align="center" min-width="170">
          <template slot-scope="scope">
            {{ scope.row.供应商名称 }}
          </template>
        </el-table-column>
        <el-table-column label="请款时间" align="center" min-width="150">
          <template slot-scope="scope">
            {{ scope.row.请款时间 }}
          </template>
        </el-table-column>
        <el-table-column label="请款人" align="center" min-width="100">
          <template slot-scope="scope">
            {{ scope.row.姓名 }}
          </template>
        </el-table-column>
        <el-table-column label="请款金额" align="center" min-width="100" prop="请款金额">
          <template slot-scope="scope">
            {{ scope.row.请款金额 }}
          </template>
        </el-table-column>
        <el-table-column label="付款" align="center" width="320">
          <template slot-scope="scope">
            <el-popover placement="right" width="400" trigger="click">
              <el-table :data="gridData2" stripe size="mini" show-summary>
                <el-table-column width="50" align="center" type="index" label="序号"/>
                <el-table-column min-width="150" align="center" label="离线合同编号">
                  <template slot-scope="scope">
                    {{ scope.row.离线合同编号 }}
                  </template>
                </el-table-column>
                <el-table-column min-width="100" align="center" label="合同总额" prop="请款金额">
                  <template slot-scope="scope">
                    {{ scope.row.请款金额 }}
                  </template>
                </el-table-column>
              </el-table>
              <el-button slot="reference" type="success" size="mini" icon="el-icon-search" style="margin-right: 10px" @click="searchTable02(scope.row)">查看详情</el-button>
            </el-popover>
            <el-button type="primary" size="mini" icon="el-icon-check" @click="yesApprovalOffline(scope.row)">通过</el-button>
            <el-button type="danger" size="mini" icon="el-icon-close" @click="noApprovalOffline(scope.row)">不通过</el-button>
          </template>
        </el-table-column>
      </el-table>
      <div class="block" style="margin-top: 10px;">
        <el-pagination
          :current-page="pageCurrent2"
          :page-sizes="[10, 20, 30, 40]"
          :page-size="pageSize2"
          :total="total2"
          style="display:inline-block;width:50%"
          layout="total, sizes, prev, pager, next, jumper"
          @size-change="handleSizeChange2"
          @current-change="handleCurrentChange2"/>
      </div>
    </el-card>
  </div>
</template>

<script>
import { initApproval, execApproval, initApprovalOffline, searchRequsetFundDetail1, searchRequsetFundDetail2, execApprovalOffline } from '@/api/PurchasingCenter/FundApproval'
import { mapGetters } from 'vuex'

export default {
  name: '', // 出纳付款
  data() {
    return {
      tableData1: [],
      pageSize1: 10,
      pageCurrent1: 1,
      total1: 0,
      tableData2: [],
      pageSize2: 10,
      pageCurrent2: 1,
      total2: 0,
      gridData1: [],
      gridData2: []
    }
  },
  computed: {
    ...mapGetters([
      'sidebar',
      'avatar',
      'name',
      'id' // 人员编号
    ])
  },
  created() {
    this.fetchData()
  },
  methods: {
    fetchData() {
      this.searchTable1()
      this.searchTable2()
    },
    searchTable1() {
      initApproval(this.pageCurrent1, this.pageSize1, 2).then(response => {
        this.tableData1 = response.data.rows
        this.total1 = response.data.total
      })
    },
    handleSizeChange1(val) {
      this.pageSize1 = val
      this.pageCurrent1 = 1
      this.searchTable1()
    },
    handleCurrentChange1(val) {
      this.pageCurrent1 = val
      this.searchTable1()
    },
    searchTable2() {
      initApprovalOffline(this.pageCurrent2, this.pageSize2, 2).then(response => {
        console.log(response.data.rows)
        this.tableData2 = response.data.rows
        this.total2 = response.data.total
      })
    },
    handleSizeChange2(val) {
      this.pageSize2 = val
      this.pageCurrent2 = 1
      this.searchTable2()
    },
    handleCurrentChange2(val) {
      this.pageCurrent2 = val
      this.searchTable2()
    },
    searchTable01(row) { // 查看详情（请款信息包含的合同）
      searchRequsetFundDetail1(row.采购合同请款流水号).then(response => {
        this.gridData1 = response.data
      })
    },
    searchTable02(row) { // 查看详情（请款信息包含的合同）
      searchRequsetFundDetail2(row.离线合同请款流水号).then(response => {
        this.gridData2 = response.data
      })
    },
    yesApproval(row) { // 通过付款
      this.$confirm('确定付款通过?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        execApproval(row.采购合同请款流水号, 1, '通过', this.id, 2).then(response => {
          if (response.data[0].result === '1') {
            this.$message.success('执行成功')
            // 记录付款金额及时间
            this.searchTable1()
          } else { this.$message.error('执行失败') }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '取消操作'
        })
      })
    },
    noApproval(row) { // 不通过付款
      this.$prompt('请输入不通过原因', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消'
      }).then(({ value }) => {
        execApproval(row.采购合同请款流水号, 2, value, this.id, 2).then(response => {
          if (response.data[0].result === '1') {
            this.$message.success('执行成功')
            this.searchTable1()
          } else { this.$message.error('执行失败') }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '取消操作'
        })
      })
    },
    yesApprovalOffline(row) { // 通过审核
      this.$confirm('确定审核通过?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        execApprovalOffline(row.离线合同请款流水号, 1, '通过', this.id, 2).then(response => {
          if (response.data[0].result === '1') {
            this.$message.success('执行成功')
            this.searchTable2()
          } else { this.$message.error('执行失败') }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '取消操作'
        })
      })
    },
    noApprovalOffline(row) { // 不通过审核
      this.$prompt('请输入不通过原因', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消'
      }).then(({ value }) => {
        execApprovalOffline(row.离线合同请款流水号, 2, value, this.id, 2).then(response => {
          if (response.data[0].result === '1') {
            this.$message.success('执行成功')
            this.searchTable2()
          } else { this.$message.error('执行失败') }
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '取消操作'
        })
      })
    }
  }
}
</script>

<style scoped>
  .el-card{
    margin-bottom: 15px;
  }
  .el-select{
    width:200px
  }
  .el-input{
    width:200px
  }
  span{
    margin: 10px 0 10px 10px;
  }
  .searchForm .el-form-item{
    margin-bottom: 5px;
  }
  .el-tag{
    margin: 0
  }
</style>
